import { IHOTPOptions } from '@zodash/hotp';
export interface ITOTP {
    /**
    * Get a OTP based HMAC-SHA-1
    *
    * @param token token string
    * @param options optional options
    */
    generate(token: string, options?: IGetOptions): Promise<string>;
    /**
     * Verify OTP is valid to Token
     *
     * @param otp one-time password
     * @param token token string
     * @param options optional options
     */
    verify(otp: string, token: string, options?: IVerifyOptions): Promise<boolean>;
    /**
     * Get TOTP URI
     *
     * @param token token string
     * @param account account
     * @param issuer issuer or organazation
     */
    getURI(token: string, account: string, issuer: string): Promise<string>;
    /**
     * Get TTL
     *
     * @param timeStep number, optional
     * @param startedAt milliseconds, optional
     */
    getTTL(timeStep?: number, startedAt?: number): Promise<number>;
}
export interface ITOTPOptions extends IHOTPOptions {
}
export interface IGetOptions {
    /**
     * Time step seconds, default: 30
     */
    timeStep?: number;
    /**
     * Started time seconds, default: 0
     */
    startedAt?: number;
    /**
     * One-time password length, default: 6
     */
    length?: number;
}
export declare type IVerifyOptions = IGetOptions;
export declare class TOTP implements ITOTP {
    private readonly options?;
    private hotp;
    constructor(options?: ITOTPOptions);
    generate(token: string, options?: IGetOptions): Promise<string>;
    verify(otp: string, token: string, options?: IVerifyOptions): Promise<boolean>;
    getURI(token: string, account: string, issuer: string): Promise<string>;
    getTTL(timeStep?: number, startedAt?: number): Promise<number>;
}
export default TOTP;
