"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TOTP = void 0;
const hotp_1 = require("@zodash/hotp");
const CONSTANTS = {
    TIME_STEP: 30,
    STARTED_AT: 0,
};
class TOTP {
    constructor(options) {
        this.options = options;
        this.hotp = new hotp_1.default(this.options);
    }
    async generate(token, options) {
        var _a, _b;
        const timeStep = (_a = options === null || options === void 0 ? void 0 : options.timeStep) !== null && _a !== void 0 ? _a : CONSTANTS.TIME_STEP;
        const startedAt = (_b = options === null || options === void 0 ? void 0 : options.startedAt) !== null && _b !== void 0 ? _b : CONSTANTS.STARTED_AT;
        const length = options === null || options === void 0 ? void 0 : options.length;
        const timeCounter = getTimeCounter(timeStep, startedAt);
        return this.hotp.generate(token, timeCounter, { length });
    }
    async verify(otp, token, options) {
        return otp === await this.generate(token, options);
    }
    async getURI(token, account, issuer) {
        return `otpauth://totp/${account}?issuer=${issuer}&secret=${token}`;
    }
    async getTTL(timeStep = 30, startedAt = 0) {
        return getTTL(timeStep, startedAt);
    }
}
exports.TOTP = TOTP;
function getTimeCounter(timeStep, startedAt, nowSeconds = Date.now()) {
    return Math.floor((nowSeconds / 1000 - startedAt) / timeStep);
}
function getTTL(timeStep = 30, startedAt = 0) {
    const now = Date.now();
    return timeStep - Math.floor(now / 1000 - startedAt) % timeStep;
}
exports.default = TOTP;
